/////////////////////////////////////////////////////////////
// A very simple command line parser. It takes command line
// arguments as input and returns them when called with their
// respective methods

class CLParser {

    int n = -1;                    // Sample size
    int segSites = -1;             // Segregating sites
    double mpd = -1.0;             // Mean pairwise difference
    int sgltons = -1;              // Singletons
    String historyFile = "";       // Input history filename
    int its = -1;                  // Iterations
    boolean genDistribs = false;   // Output simulated distrubutions
    int outputVerbosity = 0;       // Output verbosity (0 = tidy, 1 = csv)
    int distribsOnly = 0;          // Simulate distributions with no testing

    CLParser(String[] args) {

	int i;
	String arg;

	i = 0;
        while (i < args.length && args[i].startsWith("-")) {
            arg = args[i++];

            // Command Line Arguments
            // ----------------------
            //   -n  Sample size
            //   -S  Segregating sites
            //   -d  Mean pairwise difference
            //   -s  Singletons
	    //   -h  History file
            //   -i  Its
            //   -g  Generate distributions
	    //   -v  Verbosity

            if (arg.equals("-n")) {
		n = Integer.parseInt(args[i++]);
	    } else if (arg.equals("-S")) {
                segSites = Integer.parseInt(args[i++]);
            } else if  (arg.equals("-d")) {
		mpd = Double.parseDouble(args[i++]);
            } else if (arg.equals("-s")) {
                sgltons = Integer.parseInt(args[i++]);
	    } else if (arg.equals("-h")) {
		historyFile = args[i++];
            } else if (arg.equals("-i")) {
                its = Integer.parseInt(args[i++]);
            } else if (arg.equals("-g")) {
		genDistribs = true;
	    } else if (arg.equals("-v")) {
		outputVerbosity = Integer.parseInt(args[i++]);
	    }
	}
    }

    // Sample size
    public int getN()
    {
	return n;
    }

    // Mean pairwise difference
    public double getMPD()
    {
	return mpd;
    }

    // Segregating sites
    public int getSegSites()
    {
	return segSites;
    }

    // Singletons
    public int getSgltons()
    {
	return sgltons;
    }

    // History filename
    public String getHistoryFile()
    {
	return historyFile;
    }

    // Iterations
    public int getIts()
    {
	return its;
    }

    // Output simulated distributions
    public boolean getGenDistribs()
    {
	return genDistribs;
    }

    // Output verbosity (0 = tidy; 1 = csv; 
    public int getOutputVerbosity()
    {
	return outputVerbosity;
    }
}
